﻿using System.Text.Json;
using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service;

    public class QuoteServiceStub : IQuoteServiceJson
    {
        private readonly string _jsonFilePath;

        public QuoteServiceStub(string filePath)
        {
            _jsonFilePath = Path.Combine(Environment.CurrentDirectory, "wwwroot", filePath);
        }

        public async Task<List<User>> GetQuoteJson()
        {
            if (!File.Exists(_jsonFilePath))
            {
                Console.Out.WriteLine($"{_jsonFilePath} not found");
                return new List<User>();
            }

            var json = await File.ReadAllTextAsync(_jsonFilePath);
            return JsonSerializer.Deserialize<List<User>>(json) ?? new List<User>();
        }

        public async Task SaveQuoteJson(List<User> users)
        {
            var json = JsonSerializer.Serialize(users, new JsonSerializerOptions { WriteIndented = true });
            await File.WriteAllTextAsync(_jsonFilePath, json);
        }

        public async Task AddQuoteJson(User user)
        {
            var data = await GetQuoteJson();
            user.Id = data.Count > 0 ? data.Max(p => p.Id) + 1 : 1;
            data.Add(user);
            await SaveQuoteJson(data);
        }

        public async Task DeleteQuoteJson(int id)
        {
            var data = await GetQuoteJson();
            var person = data.FirstOrDefault(p => p.Id == id);
            if (person != null)
            {
                data.Remove(person);
                await SaveQuoteJson(data);
            }
        }

        public async Task UpdateQuoteJson(User user)
        {
            var data = await GetQuoteJson();
            var person = data.FirstOrDefault(p => p.Id == user.Id);
            if (person != null)
            {
                person.Name = user.Name;
                person.Email = user.Email;
                person.Image = user.Image;
                await SaveQuoteJson(data);
            }
        }

}  
   